Iterates over components using a provided bitset.
Each time the bitset has a 1 in index i, the iterator will fetch data
from the storage at index i and return it as an Option.
Iterates over components using a provided bitset.
Each time the bitset has a 1 in index i, the iterator will fetch data
from the storage at index i and return it as an Option.
A dispatcher is used to execute a collection of System in order and
possibly in parallel using World’s resources.
A dispatcher automatically avoids mutable borrow collisions which would
normally lead to data corruption, dead locks and more.
Holds a list of alive entities.
It also holds a list of entities that were recently killed, which allows
to remove components of deleted entities at the end of a game frame.
Converts a function into a System. It is required to execute a function
automatically from World’s resources.
This trait is automatically implemented for functions taking 12 arguments (16 if using the
big_systems feature)
or less where:
The result of a System’s execution.
Returns Ok(()) on success, EcsError on failure.
To return a custom error from a system, use the
system_error! macro.